@@ -15,6 +15,7 @@ import subprocess
 import typing as t
 import warnings
 
+from libtmux import exc, formats
 from libtmux._internal.query_list import QueryList
 from libtmux.common import tmux_cmd
 from libtmux.neo import fetch_objs
@@ -22,7 +23,6 @@ from libtmux.pane import Pane
 from libtmux.session import Session
 from libtmux.window import Window
 
-from . import exc, formats
 from .common import (
     EnvironmentMixin,
     PaneDict,
@@ -33,13 +33,12 @@ from .common import (
 )
 
 if t.TYPE_CHECKING:
-    import sys
     import types
+    from typing import TypeAlias
 
-    if sys.version_info >= (3, 10):
-        from typing import Self, TypeAlias
-    else:
-        from typing_extensions import Self, TypeAlias
+    from typing_extensions import Self
+
+    from libtmux._internal.types import StrPath
 
     DashLiteral: TypeAlias = t.Literal["-"]
 
@@ -431,7 +430,7 @@ class Server(EnvironmentMixin):
         session_name: str | None = None,
         kill_session: bool = False,
         attach: bool = False,
-        start_directory: str | None = None,
+        start_directory: StrPath | None = None,
         window_name: str | None = None,
         window_command: str | None = None,
         x: int | DashLiteral | None = None,
@@ -466,7 +465,7 @@ class Server(EnvironmentMixin):
         kill_session : bool, optional
             Kill current session if ``$ tmux has-session``.
             Useful for testing workspaces.
-        start_directory : str, optional
+        start_directory : str or PathLike, optional
             specifies the working directory in which the
             new session is created.
         window_name : str, optional
@@ -542,7 +541,9 @@ class Server(EnvironmentMixin):
             tmux_args += ("-d",)
 
         if start_directory:
-            tmux_args += ("-c", start_directory)
+            # as of 2014-02-08 tmux 1.9-dev doesn't expand ~ in new-session -c.
+            start_directory = pathlib.Path(start_directory).expanduser()
+            tmux_args += ("-c", str(start_directory))
 
         if window_name:
             tmux_args += ("-n", window_name)
@@ -576,7 +577,11 @@ class Server(EnvironmentMixin):
             os.environ["TMUX"] = env
 
         session_formatters = dict(
-            zip(["session_id"], session_stdout.split(formats.FORMAT_SEPARATOR)),
+            zip(
+                ["session_id"],
+                session_stdout.split(formats.FORMAT_SEPARATOR),
+                strict=False,
+            ),
         )
 
         return Session.from_session_id(
