@@ -4,6 +4,7 @@ from __future__ import annotations
 
 import logging
 import os
+import pathlib
 import subprocess
 import time
 import typing as t
@@ -14,6 +15,7 @@ from libtmux.common import has_gte_version, has_version
 from libtmux.server import Server
 
 if t.TYPE_CHECKING:
+    from libtmux._internal.types import StrPath
     from libtmux.session import Session
 
 logger = logging.getLogger(__name__)
@@ -308,3 +310,111 @@ def test_server_context_manager(TestServer: type[Server]) -> None:
 
     # Server should be killed after exiting context
     assert not server.is_alive()
+
+
+class StartDirectoryTestFixture(t.NamedTuple):
+    """Test fixture for start_directory parameter testing."""
+
+    test_id: str
+    start_directory: StrPath | None
+    description: str
+
+
+START_DIRECTORY_TEST_FIXTURES: list[StartDirectoryTestFixture] = [
+    StartDirectoryTestFixture(
+        test_id="none_value",
+        start_directory=None,
+        description="None should not add -c flag",
+    ),
+    StartDirectoryTestFixture(
+        test_id="empty_string",
+        start_directory="",
+        description="Empty string should not add -c flag",
+    ),
+    StartDirectoryTestFixture(
+        test_id="user_path",
+        start_directory="{user_path}",
+        description="User path should add -c flag",
+    ),
+    StartDirectoryTestFixture(
+        test_id="relative_path",
+        start_directory="./relative/path",
+        description="Relative path should add -c flag",
+    ),
+]
+
+
+@pytest.mark.parametrize(
+    list(StartDirectoryTestFixture._fields),
+    START_DIRECTORY_TEST_FIXTURES,
+    ids=[test.test_id for test in START_DIRECTORY_TEST_FIXTURES],
+)
+def test_new_session_start_directory(
+    test_id: str,
+    start_directory: StrPath | None,
+    description: str,
+    server: Server,
+    monkeypatch: pytest.MonkeyPatch,
+    tmp_path: pathlib.Path,
+    user_path: pathlib.Path,
+) -> None:
+    """Test Server.new_session start_directory parameter handling."""
+    monkeypatch.chdir(tmp_path)
+
+    # Format path placeholders with actual fixture values
+    actual_start_directory = start_directory
+    expected_path = None
+
+    if start_directory and str(start_directory) not in {"", "None"}:
+        if f"{user_path}" in str(start_directory):
+            # Replace placeholder with actual user_path
+            actual_start_directory = str(start_directory).format(user_path=user_path)
+            expected_path = str(user_path)
+        elif str(start_directory).startswith("./"):
+            # For relative paths, use tmp_path as base
+            temp_dir = tmp_path / "relative" / "path"
+            temp_dir.mkdir(parents=True, exist_ok=True)
+            actual_start_directory = str(temp_dir)
+            expected_path = str(temp_dir.resolve())
+
+    # Should not raise an error
+    session = server.new_session(
+        session_name=f"test_session_{test_id}",
+        start_directory=actual_start_directory,
+    )
+
+    assert session.session_name == f"test_session_{test_id}"
+    assert server.has_session(f"test_session_{test_id}")
+
+    # Verify working directory if we have an expected path
+    if expected_path:
+        active_pane = session.active_window.active_pane
+        assert active_pane is not None
+        active_pane.refresh()
+        assert active_pane.pane_current_path is not None
+        actual_path = str(pathlib.Path(active_pane.pane_current_path).resolve())
+        assert actual_path == expected_path
+
+
+def test_new_session_start_directory_pathlib(
+    server: Server,
+    user_path: pathlib.Path,
+) -> None:
+    """Test Server.new_session accepts pathlib.Path for start_directory."""
+    # Pass pathlib.Path directly to test pathlib.Path acceptance
+    session = server.new_session(
+        session_name="test_pathlib_start_dir",
+        start_directory=user_path,
+    )
+
+    assert session.session_name == "test_pathlib_start_dir"
+    assert server.has_session("test_pathlib_start_dir")
+
+    # Verify working directory
+    active_pane = session.active_window.active_pane
+    assert active_pane is not None
+    active_pane.refresh()
+    assert active_pane.pane_current_path is not None
+    actual_path = str(pathlib.Path(active_pane.pane_current_path).resolve())
+    expected_path = str(user_path.resolve())
+    assert actual_path == expected_path
