@@ -3,6 +3,7 @@
 from __future__ import annotations
 
 import logging
+import pathlib
 import shutil
 import time
 import typing as t
@@ -22,6 +23,7 @@ from libtmux.server import Server
 from libtmux.window import Window
 
 if t.TYPE_CHECKING:
+    from libtmux._internal.types import StrPath
     from libtmux.session import Session
 
 logger = logging.getLogger(__name__)
@@ -653,3 +655,105 @@ def test_window_context_manager(session: Session) -> None:
 
     # Window should be killed after exiting context
     assert window not in session.windows
+
+
+class StartDirectoryTestFixture(t.NamedTuple):
+    """Test fixture for start_directory parameter testing."""
+
+    test_id: str
+    start_directory: StrPath | None
+    description: str
+
+
+START_DIRECTORY_TEST_FIXTURES: list[StartDirectoryTestFixture] = [
+    StartDirectoryTestFixture(
+        test_id="none_value",
+        start_directory=None,
+        description="None should not add -c flag",
+    ),
+    StartDirectoryTestFixture(
+        test_id="empty_string",
+        start_directory="",
+        description="Empty string should not add -c flag",
+    ),
+    StartDirectoryTestFixture(
+        test_id="user_path",
+        start_directory="{user_path}",
+        description="User path should add -c flag",
+    ),
+    StartDirectoryTestFixture(
+        test_id="relative_path",
+        start_directory="./relative/path",
+        description="Relative path should add -c flag",
+    ),
+]
+
+
+@pytest.mark.parametrize(
+    list(StartDirectoryTestFixture._fields),
+    START_DIRECTORY_TEST_FIXTURES,
+    ids=[test.test_id for test in START_DIRECTORY_TEST_FIXTURES],
+)
+def test_split_start_directory(
+    test_id: str,
+    start_directory: StrPath | None,
+    description: str,
+    session: Session,
+    monkeypatch: pytest.MonkeyPatch,
+    tmp_path: pathlib.Path,
+    user_path: pathlib.Path,
+) -> None:
+    """Test Window.split start_directory parameter handling."""
+    monkeypatch.chdir(tmp_path)
+
+    window = session.new_window(window_name=f"test_window_split_{test_id}")
+
+    # Format path placeholders with actual fixture values
+    actual_start_directory = start_directory
+    expected_path = None
+
+    if start_directory and str(start_directory) not in {"", "None"}:
+        if f"{user_path}" in str(start_directory):
+            # Replace placeholder with actual user_path
+            actual_start_directory = str(start_directory).format(user_path=user_path)
+            expected_path = str(user_path)
+        elif str(start_directory).startswith("./"):
+            # For relative paths, use tmp_path as base
+            temp_dir = tmp_path / "relative" / "path"
+            temp_dir.mkdir(parents=True, exist_ok=True)
+            actual_start_directory = str(temp_dir)
+            expected_path = str(temp_dir.resolve())
+
+    # Should not raise an error
+    new_pane = window.split(start_directory=actual_start_directory)
+
+    assert new_pane in window.panes
+    assert len(window.panes) == 2
+
+    # Verify working directory if we have an expected path
+    if expected_path:
+        new_pane.refresh()
+        assert new_pane.pane_current_path is not None
+        actual_path = str(pathlib.Path(new_pane.pane_current_path).resolve())
+        assert actual_path == expected_path
+
+
+def test_split_start_directory_pathlib(
+    session: Session,
+    user_path: pathlib.Path,
+) -> None:
+    """Test Window.split accepts pathlib.Path for start_directory."""
+    window = session.new_window(window_name="test_window_split_pathlib")
+
+    # Pass pathlib.Path directly to test pathlib.Path acceptance
+    new_pane = window.split(start_directory=user_path)
+
+    assert new_pane in window.panes
+    assert len(window.panes) == 2
+
+    # Verify working directory
+    new_pane.refresh()
+    assert new_pane.pane_current_path is not None
+    actual_path = str(pathlib.Path(new_pane.pane_current_path).resolve())
+    expected_path = str(user_path.resolve())
+    assert actual_path == expected_path
